<?php

namespace Teknisa\CADEST\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\CADEST\Services\ImportCompService;

class ImportComp {

    protected $service;
    
    public function __construct($service) {
        $this->service = $service;
    }
	
    public function ImportarComposicao(DTO\Request $request, DTO\Response $response) {
        try {
            ini_set('max_execution_time', 1800);
		    ini_set('memory_limit', '512M');
		    set_time_limit(1800);
            $row = $request->getRow()['from'];
            foreach($row['CDPRODUTODEST'] as $produto){
                if($row['IMPORTLOCAL'] == 'S'){
                    $composicaoLocal = $this->service->getComposicaoLocal($row['CDPRODUTOORIG'], $row['CDFILIALORIG'], $row['NRORG']);
                    if(count($composicaoLocal) > 0){
                        $flag = true;
                        $this->service->checkComposicaoOrigL($composicaoLocal, $row['CDFILIALORIG'], $row['NRORG'], $produto, $flag);
                        if($flag){
                            $this->service->deleteComposicaoLocal($produto, $row['CDFILIAL'], $row['NRORG']);
                            $this->service->saveComposicaoLocal($produto, $row['CDFILIAL'], $composicaoLocal, $row['NRORG'], $row['CDPRODUTOORIG']);
                        } else {
                            $response->addMessage(new Message("Produto de Origem possui o Produto Destino em sua composição Local!", Message::TYPE_ERROR));
                            $response->addMessage(new Message("LOCAL"));
                            return $response;
                        }
                    } else {
                        $response->addMessage(new Message("Produto de Origem não possui composição Local!", Message::TYPE_ERROR));
                        $response->addMessage(new Message("LOCAL"));
                        return $response;
                    }
                }
                if($row['IMPORTPADRAO'] == 'S'){
                    $composicaoPadrao = $this->service->getComposicaoPadrao($row['CDPRODUTOORIG'],  $row['NRORG']);
                    
                    if(count($composicaoPadrao) > 0){
                        $flag = true;
                        $this->service->checkComposicaoOrigP($composicaoPadrao, $row['NRORG'], $produto, $flag);
                        if($flag){
                            $this->service->deleteComposicaoPadrao($produto, $row['NRORG']);
                            $this->service->saveComposicaoPadrao($produto, $composicaoPadrao, $row['NRORG'], $row['CDPRODUTOORIG']);
                        } else {
                            $response->addMessage(new Message("Produto de Origem possui o Produto Destino em sua composição Padrão!", Message::TYPE_ERROR));
                            $response->addMessage(new Message("PADRAO"));
                            return $response;
                        }
                    } else {
                        $response->addMessage(new Message("Produto de Origem não possui composição Padrão!", Message::TYPE_ERROR));
                        $response->addMessage(new Message("PADRAO"));
                        return $response;
                    }
                }
                if($row['IDIMPORTAGRUPOLOCAL'] == 'S'){
                    $this->service->saveGrupoPromocionalLocal($row['CDFILIAL'], $row['CDFILIALORIG'], $row['NRORG'], $row['CDPRODUTOORIG'], $produto);
                }
                if($row['IDIMPORTAGRUPOPADRAO'] == 'S'){
                    $this->service->saveGrupoPromocionalPadrao($row['NRORG'], $row['CDPRODUTOORIG'], $produto);
                }
            }
            $response->addNotification(new Notification("Importação realizada com sucesso!", Notification::TYPE_SUCCESS));
        }
        catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findProductsWithComp(DTO\Request $request, DTO\Response $response){
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            if($conditions[1]['value'] == 'L'){
                $return =  $this->service->findLocal($conditions[0]['value']);
            } else {
                $return =  $this->service->findPadrao();
            }
            $response->addDataSet(new DataSet("findProductsWithComp", $return));
        }
        catch(\Exception $e) {
            throw $e;
        }
        
    }
	
	public function ExportLocLoc(DTO\Request $request, DTO\Response $response) {
        try {

            $row = $request->getRow()['from'];
                
                if(count($row["EXPORTAR"])==2){
                    foreach($row['CDPRODUTODEST'] as $produto){
                        foreach($row['CDFILIALDEST'] as $filial){
                                $composicao = $this->service->getComposicaoLocal($produto, $row['CDFILIALORIG'],  $row['NRORG']);
                                if(count($composicao) > 0){
                                    $this->service->deleteComposicaoLocal($produto, $filial, $row['NRORG']);
                                    $this->service->saveComposicaoLocal($produto, $filial, $composicao, $row['NRORG'], $produto);
                                }
                                    $this->service->saveGrupoPromocionalLocal($filial, $row['CDFILIALORIG'], $row['NRORG'], $produto, $produto);
                        }
                    }
                }
                else {
                    if($row["EXPORTAR"][0]=='SC'){
                         foreach($row['CDPRODUTODEST'] as $produto){
                            foreach($row['CDFILIALDEST'] as $filial){
                                    $composicao = $this->service->getComposicaoLocal($produto, $row['CDFILIALORIG'],  $row['NRORG']);
                                    if(count($composicao) > 0){
                                        $this->service->deleteComposicaoLocal($produto, $filial, $row['NRORG']);
                                        $this->service->saveComposicaoLocal($produto, $filial, $composicao, $row['NRORG'], $produto);
                                    }
                            }
                        }
                        }else{
                            foreach($row['CDPRODUTODEST'] as $produto){
                                foreach($row['CDFILIALDEST'] as $filial){
                                            $this->service->saveGrupoPromocionalLocal($filial, $row['CDFILIALORIG'], $row['NRORG'], $produto, $produto);
                                }
                            }

                         }
                    }
        
                    $response->addNotification(new Notification("Exportação realizada com sucesso!", Notification::TYPE_SUCCESS));
                }
        catch(\Exception $e) {
            throw $e;
            
        }
 
    }
	
    public function ExportPadrLoc(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow()['from'];
             if(count($row["EXPORTAR"])==2){
                foreach($row['CDPRODUTODEST'] as $produto){
                    foreach($row['CDFILIALDEST'] as $filial){
                        $composicaoPadrao = $this->service->getComposicaoPadraoToLocal($produto, $row['NRORG']);
                        if(count($composicaoPadrao) > 0){
                            $this->service->deleteComposicaoLocal($produto, $filial, $row['NRORG']);
                            $this->service->saveComposicaoLocal($produto, $filial, $composicaoPadrao, $row['NRORG'], $produto);
                        }
                                $this->service->saveGrupoPromocionalPadraoToLocal($row['NRORG'], $produto, $filial);
                    }
                }
            } else {
                    if($row["EXPORTAR"][0]=='SC'){
                        foreach($row['CDPRODUTODEST'] as $produto){
                            foreach($row['CDFILIALDEST'] as $filial){
                                $composicaoPadrao = $this->service->getComposicaoPadraoToLocal($produto, $row['NRORG']);
                                if(count($composicaoPadrao) > 0){
                                    $this->service->deleteComposicaoLocal($produto, $filial, $row['NRORG']);
                                    $this->service->saveComposicaoLocal($produto, $filial, $composicaoPadrao, $row['NRORG'], $produto);
                                    
                                }
                            }
                        }
                    }else{
                        foreach($row['CDPRODUTODEST'] as $produto){
                            foreach($row['CDFILIALDEST'] as $filial){
                                $composicaoPadrao = $this->service->getComposicaoPadraoToLocal($produto, $row['NRORG']);
            
                                        $this->service->saveGrupoPromocionalPadraoToLocal($row['NRORG'], $produto, $filial);
                            }
                        }
                    }
              }
            
            $response->addNotification(new Notification("Exportação realizada com sucesso!", Notification::TYPE_SUCCESS));
        }
        catch(\Exception $e) {
            throw $e;
        }
    }
	
    public function ExportLocPadr(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow()['from'];
                if(count($row["EXPORTAR"])==2){
                    foreach($row['CDPRODUTODEST'] as $produto){
                        $composicaoLocal = $this->service->getComposicaoLocalToPadrao($produto, $row['CDFILIAL'], $row['NRORG']);
                            if(count($composicaoLocal) > 0){
                                $this->service->deleteComposicaoPadrao($produto, $row['NRORG']);
                                $this->service->saveComposicaoPadrao($produto, $composicaoLocal, $row['NRORG'], $produto);
                                
                            }
                                    $this->service->saveGrupoPromocionalLocalToPadrao($row['CDFILIAL'], $row['NRORG'], $produto);
                    }
                }else{
                    if($row["EXPORTAR"][0]=='SC'){
                        foreach($row['CDPRODUTODEST'] as $produto){
                            $composicaoLocal = $this->service->getComposicaoLocalToPadrao($produto, $row['CDFILIAL'], $row['NRORG']);
                                if(count($composicaoLocal) > 0){
                                    $this->service->deleteComposicaoPadrao($produto, $row['NRORG']);
                                    $this->service->saveComposicaoPadrao($produto, $composicaoLocal, $row['NRORG'], $produto);
                                }
                        }
                    }else{
                        foreach($row['CDPRODUTODEST'] as $produto){
                            $composicaoLocal = $this->service->getComposicaoLocalToPadrao($produto, $row['CDFILIAL'], $row['NRORG']);
                                $this->service->saveGrupoPromocionalLocalToPadrao($row['CDFILIAL'], $row['NRORG'], $produto);
                        }
                    }
                }
            $response->addNotification(new Notification("Exportação realizada com sucesso!", Notification::TYPE_SUCCESS));
        }
        catch(\Exception $e) {
            throw $e;
        }
    }
}